@@ -1,8 +1,10 @@
-# Preamble code
+# Preamble code ----------------------------------------------------------------
 data("traits_birds")
 traits_birds_sc <- scale(traits_birds)
 
-# Actual tests
+
+# Tests for valid inputs -------------------------------------------------------
+
 test_that("Functional Dispersion output format", {
 
   fdis <- expect_silent(fd_fdis(traits_birds))
@@ -73,6 +75,9 @@ test_that("Functional Dispersion works with sparse matrices", {
 
 })
 
+
+# Tests for invalid inputs -----------------------------------------------------
+
 test_that("Functional Dispersion fails gracefully", {
 
   # No traits
@@ -88,4 +93,17 @@ test_that("Functional Dispersion fails gracefully", {
            "and site-species matrix"),
     fixed = TRUE
   )
+
+  ## Categorical trait data
+  # Add non-continuous traits
+  traits_birds_cat <- as.data.frame(traits_birds_sc)
+  traits_birds_cat$cat_trait <- "a"
+
+  expect_error(
+    fd_fdis(traits_birds_cat, site_sp_birds),
+    paste0("Non-continuous trait data found in input traits. ",
+           "Please provide only continuous trait data"),
+    fixed = TRUE
+  )
 })
+
