@@ -1,8 +1,10 @@
-# Preamble code
+# Preamble code ----------------------------------------------------------------
 data("traits_birds")
 data("site_sp_birds")
 
-# Actual tests
+
+# Tests for valid inputs -------------------------------------------------------
+
 test_that("Functional Richness Intersection output format", {
 
   fric_int <- expect_silent(fd_fric_intersect(traits_birds))
@@ -149,6 +151,9 @@ test_that("Functional Richness Intersection works on sparse matrices", {
     1, tolerance = 1e-6)
 })
 
+
+# Tests for invalid inputs -----------------------------------------------------
+
 test_that("Functional Richness Intersection fails gracefully", {
 
   # No traits
@@ -164,4 +169,16 @@ test_that("Functional Richness Intersection fails gracefully", {
            "and site-species matrix"),
     fixed = TRUE
   )
+
+  ## Categorical trait data
+  # Add non-continuous traits
+  traits_birds_cat <- as.data.frame(traits_birds)
+  traits_birds_cat$cat_trait <- "a"
+
+  expect_error(
+    fd_fric_intersect(traits_birds_cat, site_sp_birds),
+    paste0("Non-continuous trait data found in input traits. ",
+           "Please provide only continuous trait data"),
+    fixed = TRUE
+  )
 })
